get_cluster_result: Obtain the clustering result

Description Usage Arguments Examples

View source: R/get_clsuter_result.R

Description

This function obtains the clustering result from reCAT, bayes and mean scores, and the time series ordering.

Usage

1
get_cluster_result(test_exp, ensembleResultLst, resultLst, cls_num)

Arguments

test_exp

The pre-processed input data

ensembleResultLst

This can be obtained from the automatically saved .RData file in your working directory.

resultLst

This can be obtained from the automatically saved .RData file in your working directory.

cls_num

The desired number of clusters to view (value > 10)

Examples

1
2
3
4
5
6
test_exp <- get_test_exp(data)
data_ordIndex <- get_ordIndex(test_exp, 2)
# Load the following .RData file from your local working directory, it is automatically generated when you perform the function 'get_ordIndex'
load("../data/bestEnsembleComplexTSP 10 - N  .RData")
cls_result = get_cluster_result(test_exp = test_exp, ensembleResultLst = ensembleResultLst,
                               resultLst = resultLst, cls_num = 20)

tinglabs/reCAT documentation built on March 16, 2021, 12:08 a.m.