get_hmm_order: Segmenting cell cycle stages

Description Usage Arguments Examples

View source: R/get_hmm.R

Description

This function is used segment the cells into the different cell cycle stages

Usage

1
get_hmm_order(bayes_score, mean_score, ordIndex, cls_num, myord, rdata = NULL)

Arguments

bayes_score

Obtained from get_score function

mean_score

Obtained from get_score function

ordIndex

Obtained from get_ordIndex function

cls_num

The number of cell cycle stages that you want to segment, ie 3 - G1, S, G2/M.

rdata

This sets the region of each cycle stage manually by observing the scores. Usage: rdata = t(data.frame(c(2,5), c(10,15), c(20,25))) corresponding to G1: 2-5, S: 10-15 and G2/M: 20-25. If NULL, it will prompt you to enter the region values such as '2 5', please enter twice to confirm each line of input.

fob

Sets the forward (=1) or backward (=0) direction of the ordered timeseries.

Examples

1
2
3
4
5
test_exp <- get_test_exp(data)
data_ordIndex <- get_ordIndex(test_exp, 2)
score_results <- get_score(t(test_exp))
rdata = t(data.frame(c(2,5), c(10,15), c(20,25)))
hmm_results <- get_hmm_order(score_results$bayes_score, score_results$mean_score, cls_num = 3, rdata, data_ordIndex, fob=1)

tinglabs/reCAT documentation built on March 16, 2021, 12:08 a.m.