get_ordIndex: Perform reCAT

Description Usage Arguments Examples

View source: R/get_ordIndex.R

Description

This function performs reCAT on your data, generating the order index of each cell as output.

Usage

1
2
3
4
5
6
7
8
get_ordIndex(
  test_exp,
  threadnum,
  step_size = 2,
  base_cycle_range = c(6:9),
  max_loop = NULL,
  clust_method = NULL
)

Arguments

test_exp

The gene expression input obtained from get_test_exp

threadnum

The number of threads to use

step_size

The interval of cycles to merge in the algorithm. Defaults to 2

base_cycle_range

Sets the cluster number used to formulate the base cycle, can be set as c(6:9) or c(7:10). Defaults to c(6:9)

max_loop

This sets the maximum number for not applying step_size in reCAT, i.e. if N = 100, step_size = 5, and max_loop = 50. Then reCAT merges consecutive cycles from 10 to 50, then merges cycles by intervals of 5 from 55 to 100.

clust_method

There are two clustering approaches: GMM ("GMM") and correlation-based ("Corr"). This defaults to NULL, where reCAT uses "GMM" for datasets with less than 300 cells and "Corr" for > 300. We recommend "GMM" for better accuracy but only for small datasets (as it fails to cluster on larger datasets), and "Corr" for efficiency and larger datasets.

Examples

1
get_ordIndex(data, threadnum = 2, step_size = 2, base_cycle_range = c(6:9))

tinglabs/reCAT documentation built on March 16, 2021, 12:08 a.m.