get_score: Bayes scores and mean scores

Description Usage Arguments Examples

View source: R/get_score.R

Description

This function produces the bayes scores (G1, S, G2/M) and Mean scores (G1, S, G2, M, G1/S, G2/M) over the dataset. The output can then be used to classify different cycle stages using HMM.

Usage

1
get_score(talentDE)

Arguments

data

The data with cycling genes, m genes by n cells

Examples

1
2
test_exp <- get_test_exp(data)
get_score(t(test_exp))

tinglabs/reCAT documentation built on March 16, 2021, 12:08 a.m.