get_test_exp: Pre-processing the gene expression

Description Usage Arguments Examples

View source: R/get_test_exp.R

Description

This function is used to get the correct input to reCAT and automatically selects the cycling genes from the Cyclebase

Usage

1

Arguments

data

The gene expression data input, m genes by n cells

Examples

1

tinglabs/reCAT documentation built on March 16, 2021, 12:08 a.m.