reCAT-package: reCAT: Reconstructing Cell Cycle Pseudo Time-Series via...

Description Author(s) References

Description

reCAT is a modelling framework for unsynchronized single-cell transcriptome data that can reconstruct a high-resolution cell cycle time-series. It is mainly based on traveling salesman problem (TSP), Gaussian mixture model (GMM) and hidden Markov model (HMM). We developed an R based software package which is easy to use. The performance is relatively accurate and stable. Thanks for using!

Author(s)

Maintainer: Zehua Liu zehualiuf@hotmail.com

Authors:

References

Liu, Z., Lou, H., Xie, K., Wang, H., Chen, N., Aparicio, O.M., Zhang, M.Q., Jiang, R. and Chen, T., 2017. Reconstructing cell cycle pseudo time-series via single-cell transcriptome data. Nature communications, 8(1), pp.1-9.


tinglabs/reCAT documentation built on March 16, 2021, 12:08 a.m.