Description Usage Arguments Examples
This function produces the bayes scores (G1, S, G2/M) and Mean scores (G1, S, G2, M, G1/S, G2/M) over the dataset. The output can then be used to classify different cycle stages using HMM.
1 | get_score(talentDE)
|
data |
The data with cycling genes, m genes by n cells |
1 2 | test_exp <- get_test_exp(data)
get_score(t(test_exp))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.