Description Usage Arguments Examples
This function is used to get the correct input to reCAT and automatically selects the cycling genes from the Cyclebase
1 |
data |
The gene expression data input, m genes by n cells |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.