Description Author(s) References
reCAT is a modelling framework for unsynchronized single-cell transcriptome data that can reconstruct a high-resolution cell cycle time-series. It is mainly based on traveling salesman problem (TSP), Gaussian mixture model (GMM) and hidden Markov model (HMM). We developed an R based software package which is easy to use. The performance is relatively accurate and stable. Thanks for using!
Maintainer: Zehua Liu zehualiuf@hotmail.com
Authors:
Huazhe Lou [contributor]
Ken Xie [contributor]
Hao Wang [contributor]
Liu, Z., Lou, H., Xie, K., Wang, H., Chen, N., Aparicio, O.M., Zhang, M.Q., Jiang, R. and Chen, T., 2017. Reconstructing cell cycle pseudo time-series via single-cell transcriptome data. Nature communications, 8(1), pp.1-9.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.